@@ -67,10 +67,9 @@ rm -rf test.sd >/dev/null 2>&1
 
 #   result
 if [ $failed -gt 0 ]; then
-    rc="FAILED"
+    echo "FAILED: passed: $passed/$ran, failed: $failed/$ran"
 else
-    rc="OK"
+    echo "OK: passed: $passed/$ran"
 fi
-echo "$rc: passed: $passed/$ran, failed: $failed/$ran"
 exit 0
 
